package com.auth

import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import androidx.localbroadcastmanager.content.LocalBroadcastManager
import com.android.dingtalk.share.ddsharemodule.DDShareApiFactory
import com.android.dingtalk.share.ddsharemodule.IDDShareApi
import com.android.dingtalk.share.ddsharemodule.message.SendAuth
import com.auth.DDShareActivity.Companion.BROADCAST

class DingAuth : BroadcastReceiver {

    private var context: Context
    private var appId: String
    private var iddShareApi: IDDShareApi

    constructor(context: Context, appId: String) {
        this.context = context
        this.appId = appId
        iddShareApi = DDShareApiFactory.createDDShareApi(context, appId, false)
    }

    private var callback: OnAuthCallback? = null

    fun doAuth(callback: OnAuthCallback) {
        this.callback = callback
        val request: SendAuth.Req = SendAuth.Req()
        request.scope = SendAuth.Req.SNS_LOGIN
        request.state = "auth"
        iddShareApi.sendReq(request)
        LocalBroadcastManager.getInstance(context).registerReceiver(this, IntentFilter(BROADCAST))
    }

    override fun onReceive(context: Context, intent: Intent?) {
        val state: Int? = intent?.getIntExtra("type", 0)
        val code: String? = intent?.getStringExtra("code")
        if (state == 1) {
            if (code != null) {
                callback?.onSuccess(code)
            }
        } else {
            if (code != null) {
                callback?.onFailed(code)
            }
        }
        LocalBroadcastManager.getInstance(context).unregisterReceiver(this)
    }
}

interface OnAuthCallback {

    fun onSuccess(code: String)

    fun onFailed(code: String)

}